<?php
/**
 * Copyright (C) 2019 Leipzig University Library
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * @author  Alexander Purr <purr@ub.uni-leipzig.de>
 * @license http://opensource.org/licenses/gpl-2.0.php GNU GPLv2
 */
use fid\Hydrator\OrderHydrator;
use Laminas\Filter\StringTrim;
use Laminas\Form\Element\Select;
use Laminas\Form\Element\Submit;
use Laminas\Form\Element\Textarea;
use Laminas\Form\Element\Url;
use Laminas\Validator\StringLength;

return [
    'name'         => 'fid-acquisition-form',
    'hydrator'     => OrderHydrator::class,
    'elements'     => [
        'library'              => [
            'spec' => [
                'name'       => 'library',
                'type'       => Text::class,
                'options'    => [
                    'label' => 'acquisition_label_library',
                ],
                'attributes' => [
                  'id' => "library",
                ],
            ],
        ],
        'signature'              => [
            'spec' => [
                'name'       => 'signature',
                'type'       => Text::class,
                'options'    => [
                    'label' => 'acquisition_label_signature',
                ],
                'attributes' => [
                  'id' => "signature",
                ],
            ],
        ],
        'external_url'              => [
            'spec' => [
                'name'       => 'external_url',
                'type'       => Url::class,
                'options'    => [
                    'label' => 'acquisition_label_external_url',
                ],
                'attributes' => [
                  'id' => "external_url",
                ],
            ],
        ],
        'format'            => [
            'spec' => [
                'name'    => 'format',
                'type'    => Select::class,
                'options' => [
                    'label'        => 'acquisition_label_format',
                    'options'      => [
                        'pdf'  => [
                            'value' => 'pdf',
                            'label' => 'PDF',
                        ],
                        'jpg' => [
                            'value' => 'jpg',
                            'label' => 'JPG',
                        ],
                    ],
                ],
                'attributes' => [
                  'id' => "format",
                ],
            ],
        ],
        'comment'              => [
            'spec' => [
                'name'       => 'comment',
                'type'       => Textarea::class,
                'options'    => [
                    'label' => 'acquisition_label_comment',
                ],
                'attributes' => [
                    'required' => false,
                    'id' => "comment",
                ],
            ],
        ],
        'submit'               => [
            'spec' => [
                'name'       => 'submit',
                'type'       => Submit::class,
                'attributes' => [
                    'value' => 'acquisition_label_submit',
                ],
            ],
        ],
    ],
    'input_filter' => [
        'library'               => [
            'name'       => 'library',
            'required'   => false,
            'filters'    => [
                StringTrim::class => [
                    'name' => StringTrim::class,
                ],
            ],
            'validators' => [
                StringLength::class => [
                    'name'    => StringLength::class,
                    'options' => [
                        'max' => 1000
                    ],
                ],
            ],
        ],
        'signature'               => [
            'name'       => 'signature',
            'required'   => false,
            'filters'    => [
                StringTrim::class => [
                    'name' => StringTrim::class,
                ],
            ],
            'validators' => [
                StringLength::class => [
                    'name'    => StringLength::class,
                    'options' => [
                        'max' => 1000
                    ],
                ],
            ],
        ],
        'external_url'               => [
            'name'       => 'external_url',
            'required'   => false,
            'filters'    => [
                StringTrim::class => [
                    'name' => StringTrim::class,
                ],
            ],
            'validators' => [
                StringLength::class => [
                    'name'    => StringLength::class,
                    'options' => [
                        'max' => 1000
                    ]
                ],
            ],
        ],
        'format'               => [
            'name'     => 'format',
            'required' => true,
        ],
        'comment'       => [
            'name'       => 'comment',
            'required'   => false,
            'filters'    => [
                StringTrim::class => [
                    'name' => StringTrim::class,
                ],
            ],
            'validators' => [
                StringLength::class => [
                    'name'    => StringLength::class,
                    'options' => [
                        'max' => 5000
                    ]
                ],
            ],
         ],
        'submit'               => [
            'name'     => 'submit',
            'required' => true,
        ],
    ],
];
