<?php
/**
 * Search Trait
 *
 * PHP version 7
 *
 * Copyright (C) Villanova University 2023.
 * Copyright (C) Leipzig University Library 2023.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * @category VuFind
 * @package  Controller
 * @author   Frank Morgner   <morgner.f@ub.uni-leipzig.de>
 * @author   Robert Lange <lange@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     http://vufind.org   Main Site
 */
namespace finc\Controller\CustomTraits;

/**
 * Search Trait
 *
 * @category VuFind
 * @package  Controller
 * @author   Robert Lange <lange@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     http://vufind.org   Main Site
 */
trait LockAccountTrait
{
    /**
     * Enable view of locking account by user
     *
     * @return mixed
     */
    public function lockAccountAction()
    {
        // Stop now if the user does not have valid catalog credentials available:
        if (!is_array($patron = $this->catalogLogin())) {
            return $patron;
        }

        if ($this->formWasSubmitted('submitLockAccount')
            && $this->params()->fromPost('lock_account') == "1"
        ) {
            // Connect to the ILS:
            $catalog = $this->getILS();
            $isSuccess = $catalog->setLockMyAccount($patron);
            if ($isSuccess === false) {
                $this->flashMessenger()->addMessage(
                    'finclibero_lock_account_error', 'error'
                );
            } else {
                $this->getAuthManager()->logout('/', false);
                $this->flashMessenger()->addMessage(
                    'finclibero_lock_account_locked', 'success'
                );
                return $this->redirect()->toUrl(
                    $this->getServerUrl('home')
                );

            }
        }
        return $this->createViewModel();
    }
}
